<?php

// Load required libraries, e.g., Guzzle for making HTTP requests
require 'vendor/autoload.php';

function getTransactions($blockType, $minAmount, $maxAmount, $numInputAddresses, $numOutputAddresses) {
    // Your Blockchain.com API Key
    $api_key = "cd0edb9b-4b1f-46ea-911a-98a39189de80";

    // Determine the block to search
    $block = $blockType == 'last' ? 'latestblock' : 'unconfirmed-transactions';
    
    // Create an HTTP client
    $client = new GuzzleHttp\Client();

    // Send a request to the Blockchain.com API
    $response = $client->request('GET', "https://blockchain.info/$block?api_code=$api_key");

    // Check for a successful response
    if ($response->getStatusCode() == 200) {
        // Parse the JSON response
        $data = json_decode($response->getBody(), true);

        // Initialize an empty array to store the transaction info
        $transactionsInfo = [];

        // Iterate through the transactions in the block
        foreach ($data['txs'] as $transaction) {
            // Check the criteria for amount, input, and output addresses
            $totalAmount = array_sum(array_column($transaction['out'], 'value'));
            if ($totalAmount >= $minAmount && $totalAmount <= $maxAmount &&
                count($transaction['inputs']) == $numInputAddresses &&
                count($transaction['out']) == $numOutputAddresses) {

                // Build the transaction info array
                $transactionInfo = [
                    'amount' => $totalAmount,
                    'transaction_hash' => $transaction['hash'],
                    'input_address' => array_column($transaction['inputs'], 'prev_out.addr'),
                    'output_address' => array_column($transaction['out'], 'addr'),
                    'date_time' => date('Y-m-d H:i:s', $transaction['time'])
                ];

                // Append the transaction info to the transactions info array
                $transactionsInfo[] = $transactionInfo;
            }
        }

        return $transactionsInfo;
    } else {
        throw new Exception("Failed to retrieve block data");
    }
}

// Usage
try {
    $transactions = getTransactions('last', 0.01, 10, 1, 2);
    print_r($transactions);
} catch (Exception $e) {
    echo "Error: " . $e->getMessage();
}

?>
